from __future__ import print_function
from distutils.util import strtobool

import os
import re
import requests
from requests.packages.urllib3.exceptions import InsecureRequestWarning
try:
    from urlparse import urljoin
except:
    from urllib.parse import urljoin

# Disable the InsecureRequestWarning
requests.packages.urllib3.disable_warnings(InsecureRequestWarning)

# https://requests.readthedocs.io/en/master/user/advanced/#ssl-cert-verification
OVPN_SSL_VERIFY = strtobool(os.environ.get('OVPN_SSL_VERIFY', 'true')) and None
OVPN_URL = os.environ['OVPN_URL']
OVPN_LOGIN = os.environ['OVPN_LOGIN']
OVPN_PASSWORD = os.environ['OVPN_PASSWORD']
OVPN_CERT_NAME = os.environ['OVPN_CERT_NAME']

session = requests.Session()

response = session.get(urljoin(OVPN_URL, '/login'), verify=OVPN_SSL_VERIFY)
response.raise_for_status()

m = re.search(r"""(?<=name="_xsrf" value=")(?P<xsrf_token>[^"]*)""", response.text, flags=re.MULTILINE)
if not m:
    raise RuntimeError("XSRF not found")

xsrf_token = m.group('xsrf_token')

response = session.post(
    urljoin(OVPN_URL, '/login'),
    data={
        'login': OVPN_LOGIN,
        'password': OVPN_PASSWORD,
        '_xsrf': xsrf_token,
    },
    verify=OVPN_SSL_VERIFY
)
response.raise_for_status()
if response.url != urljoin(OVPN_URL, '/'):
    raise RuntimeError("Login failed")


response = session.get(
    urljoin(OVPN_URL, '/certificates'),
    verify=OVPN_SSL_VERIFY
)
response.raise_for_status()
m = re.search(r"""(?<=<a href="/certificates/single-config/%s">)(?P<ovpn_file>[^<]*)""" % OVPN_CERT_NAME, response.text, flags=re.MULTILINE)
if not m:
    print("Certificate %s not found issuing a new one." % OVPN_CERT_NAME)
    response = session.post(
        urljoin(OVPN_URL, '/certificates'),
        data={
            'Name': OVPN_CERT_NAME,
        },
        verify=OVPN_SSL_VERIFY
    )
    response.raise_for_status()


response = session.get(
    urljoin(OVPN_URL, '/certificates/single-config/%s' % OVPN_CERT_NAME),
    verify=OVPN_SSL_VERIFY
)
response.raise_for_status()

# Function to delete lines beginning with 'keysize' in the certificate when connecting to <2.8 VPN version
def delete_keysize_line(cert_text):
    lines = cert_text.split('\n')
    modified_lines = [line for line in lines if not line.strip().startswith('keysize')]
    return '\n'.join(modified_lines)

# Deleting lines beginning with 'keysize'
ovpn_cert_text = delete_keysize_line(response.text)

with open('files/connection.ovpn', 'w') as fn:
    print(ovpn_cert_text, file=fn)
