#!/bin/bash

# Function to prompt user for input with default value
prompt_with_default() {
    local var_name=$1
    local default_value=$2

    # Prompt user for input
    read -p "Enter the value for $var_name [Default: $default_value]: " user_input

    # Set variable to user input or default value if input is empty
    if [ -z "$user_input" ]; then
        eval "$var_name=\"$default_value\""
    else
        eval "$var_name=\"$user_input\""
    fi
}

# uuidgen
UUID_TOKEN=$(uuidgen)
prompt_with_default HOSTNAME "hydra"
echo "Enabled Services: issuegen, openvpn, wazuh, suricata"
prompt_with_default DISABLE_SERVICES "['openvas', 'patrowl-engine-openvas', 'nodeexporter']"
# disable SSL certificate validation as self-signed certs are used
prompt_with_default OVPN_SSL_VERIFY false
prompt_with_default OVPN_URL "https://bastion.tenant1.example.com:8443/"
prompt_with_default OVPN_LOGIN "admin"
prompt_with_default OVPN_PASSWORD "bastion-pass"
# each time generate new OpenVPN certificate
OVPN_CERT_NAME="$HOSTNAME-$UUID_TOKEN"

# define to use with Kubernetes installation
# Kafka: inside-0.kafka.{{ K8S_DOMAIN }}
prompt_with_default K8S_DOMAIN "tenant1.example.com"
prompt_with_default TENANT_NAME "tenant1"
prompt_with_default NODE_NAME "hydra-node"
prompt_with_default KEY_NAME "wazuh_cluster_key"

# Export all variables
export UUID_TOKEN
export HOSTNAME
export DISABLE_SERVICES
export OVPN_SSL_VERIFY
export OVPN_URL
export OVPN_LOGIN
export OVPN_PASSWORD
export OVPN_CERT_NAME
export K8S_DOMAIN
export TENANT_NAME
export NODE_NAME
export NODE_IP
export KEY_NAME

DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

rm -rf config-drive build
mkdir -p config-drive/openstack/latest

export DOCKER_CREDENTIALS=''

echo "Retrieving VPN certificate..."
python3 get_ovpn_file.py

j2 --filters=j2_custom_filters.py files/linux/ubuntu/cloud-init.j2 > config-drive/openstack/latest/user-data
cp files/linux/ubuntu/meta-data config-drive/openstack/latest/meta-data

j2 --filters=j2_custom_filters.py files/linux/ubuntu/bare_metal.sh.j2 > bare_metal.sh
chmod +x bare_metal.sh
